#!/usr/bin/env python

from matplotlib import pyplot
from matplotlib import ticker
from matplotlib import numpy

# This generates population graphs for the foreign resident population of Japan.
# The population is broken down by country.  Data is from Wikipedia.
#
# https://en.wikipedia.org/wiki/Demographics_of_Japan#Foreign_residents
#
# SVG files are produced using matplotlib.
#
# http://xmodulo.com/matplotlib-scientific-plotting-linux.html
# http://cs.smith.edu/dftwiki/index.php/MatPlotLib_Tutorial_1
#
# This file was written by Douglas Perkins.
# It is released under a Creative Commons 4.0 Attribution license.
# The resultant SVG file is released under the same license.
# 
# https://creativecommons.org/licenses/by/4.0/

data = [
("China",	665847),
("South Korea",	457772),
("Philippines",	229595),
("Brazil",	173437),
("Vietnam",	146956),
("Nepal",	54775),
("U.S.A.",	52271),
("Taiwan",	48723),
("Peru",	47721),
("Thailand",	45379),
]

countries = [country for (country, population) in data]
populations = [population for (country, population) in data]

listed_population = 0

for population in populations:
	listed_population += population

total_population = 2232189
unlisted_population = total_population - listed_population
populations.append(unlisted_population)
countries.append("Other")

# A formatter to display comma-separated numbers on the y axis.
def comma_func(y, pos):
	s = '{:0,d}'.format(int(y))
	return s

comma_format = ticker.FuncFormatter(comma_func)

# Make a bar graph.
x = numpy.arange(len(countries)) + 0.25
width = 0.5
pyplot.figure(num=1, figsize=(9,2.5))
pyplot.bar(x, populations, width, color='m')
pyplot.title('2015 Foreign Resident Population of Japan')
pyplot.ylabel('People')
pyplot.xlabel('Nationality')
xticks = pyplot.xticks(x, countries, rotation='vertical')
pyplot.subplot(111).yaxis.set_major_formatter(comma_format)
pyplot.subplot(111).grid(b=True, axis='y')
pyplot.savefig('Nationality.Bar.svg', format='svg', bbox_inches='tight')
